@@ -1,6 +1,6 @@
 
 plot.tscgm <- function(x, mat=c("precision","autoregression"),...){
-  mat=match.arg(mat)
+  mat = match.arg(mat)
   if (mat == "precision") {
       prec <- x$theta
       #colnames(prec) <- rownames(prec) <- colnames(data)
@@ -8,7 +8,7 @@ plot.tscgm <- function(x, mat=c("precision","autoregression"),...){
       plot.network(nw_full,label = network.vertex.names(nw_full), usearrows = FALSE,
          displayisolates = FALSE,...)
    }
- else if (mat == "autoregression") {
+ if (mat == "autoregression") {
       autoR <- x$gamma
       #colnames(autoR) <- rownames(autoR) <- colnames(data)
       nw_full <- network(autoR, loops=TRUE)
